/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-25 11:18:18.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.common;

import com.fasterxml.jackson.annotation.JsonIgnore;
import springfox.documentation.annotations.ApiIgnore;

import java.io.Serializable;

import static cn.com.qmth.examcloud.core.print.common.Constants.*;

/**
 * 响应结果类
 */
public class Result<T> implements Serializable {
    private static final long serialVersionUID = 1L;
    /**
     * 状态码
     */
    private String code;
    /**
     * 描述信息
     */
    private String desc;
    /**
     * 结果数据
     */
    private T data;

    public Result(String code, String desc, T data) {
        this.code = code;
        this.desc = desc;
        this.data = data;
    }

    public Result(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    public static Result success() {
        return success(null);
    }

    public static <T> Result success(T data) {
        return new Result(PRT_CODE_200, "操作成功！", data);
    }

    public static Result error() {
        return error("操作失败！");
    }

    public static Result error(String desc) {
        return new Result(PRT_CODE_500, desc);
    }

    public static Result noAuth() {
        return new Result(PRT_CODE_403, "无效认证信息，请先登录！");
    }

    @JsonIgnore
    @ApiIgnore
    public boolean isSuccess() {
        if (PRT_CODE_200.equals(getCode())) {
            return true;
        }
        return false;
    }

    public String getCode() {
        return code;
    }

    public String getDesc() {
        return desc;
    }

    public T getData() {
        return data;
    }

}