/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-17 15:18:02.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.common.jpa;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.Optional;
import java.util.stream.Collectors;

/**
 * @author: fengdesheng
 * @since: 2018/10/17
 */
public class Model {

    public static <T> T of(Optional<T> optional) {
        try {
            if (optional != null) {
                return optional.get();
            }
        } catch (NoSuchElementException e) {
            //ignore
        }
        return null;
    }

    public static String splitFieldName(String fieldName) {
        if (fieldName == null) {
            return null;
        }
        StringBuffer result = new StringBuffer();
        char[] chars = fieldName.toCharArray();
        final int A = 65, Z = 90, DOT = 46;
        for (int i = 0; i < chars.length; i++) {
            Character c = chars[i];
            if (i == 0) {
                result.append(c);
                continue;
            }
            if (c == DOT) {
                result.append("_");
                continue;
            }
            if (c >= A && c <= Z) {
                result.append("_");
            }
            result.append(c);
        }
        return result.toString().toUpperCase();
    }

    public static List<String> parseFields(final Class clazz) {
        return parseFields(clazz, null);
    }

    public static List<String> parseFields(final Class clazz, final Class rootClazz) {
        List<String> fieldNames = new ArrayList<>();
        Field[] fields = clazz.getDeclaredFields();
        for (Field field : fields) {
            if (Modifier.isStatic(field.getModifiers())) {
                continue;
            }
            if (Modifier.isFinal(field.getModifiers())) {
                continue;
            }
            Class<?> fieldType = field.getType();
            String fieldName = field.getName();
            if (rootClazz != null && rootClazz.isAssignableFrom(fieldType)) {
                List<String> subFieldNames = parseFields(fieldType, rootClazz);
                if (subFieldNames.size() == 0) {
                    continue;
                }
                fieldNames.addAll(subFieldNames.stream()
                        .map(subName -> subName = fieldName + "." + subName)
                        .collect(Collectors.toList()));
            } else {
                fieldNames.add(fieldName);
            }
        }
        return fieldNames;
    }

}