/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-23 16:47:59.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.common.jpa;

import org.springframework.data.domain.Sort;

import java.util.ArrayList;
import java.util.List;

/**
 * 排序条件构建类
 *
 * @author: fengdesheng
 * @since: 2018/10/23
 */
public class OrderBuilder {
    private List<Order> orders;

    public OrderBuilder() {
        orders = new ArrayList<>();
    }

    public OrderBuilder asc(String fieldName) {
        orders.add(new Order(fieldName, Sort.Direction.ASC));
        return this;
    }

    public OrderBuilder desc(String fieldName) {
        orders.add(new Order(fieldName, Sort.Direction.DESC));
        return this;
    }

    public Sort build() {
        if (orders.size() == 0) {
            return null;
        }
        List<Sort.Order> list = new ArrayList<>();
        for (Order order : orders) {
            list.add(new Sort.Order(order.getDirection(), order.getFieldName()));
        }
        return new Sort(list);
    }

    public static class Order {
        private String fieldName;
        private Sort.Direction direction;

        private Order(String fieldName, Sort.Direction direction) {
            if (fieldName == null || "".equals(fieldName.trim())) {
                throw new IllegalArgumentException("FieldName must be not empty.");
            }
            this.fieldName = fieldName.trim();
            this.direction = direction;
        }

        public String getFieldName() {
            return fieldName;
        }

        public Sort.Direction getDirection() {
            return direction;
        }
    }

}