/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-17 15:18:02.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.common.jpa;

import java.util.Collection;

import static cn.com.qmth.examcloud.core.print.common.jpa.SqlWrapper.Constant.*;

/**
 * SQL常用的语句构建类
 *
 * @author: fengdesheng
 * @since: 2018/10/17
 */
public class SqlWrapper {
    private StringBuilder sql = new StringBuilder();

    public String build() {
        return sql.toString();
    }

    public SqlWrapper append(String str) {
        sql.append(str);
        return this;
    }

    public SqlWrapper as(String name) {
        sql.append(AS).append(name);
        return this;
    }

    public SqlWrapper select() {
        sql.append(SELECT).append("*");
        return this;
    }

    public SqlWrapper select(String columns) {
        /* 多个字段须按逗号分隔 */
        sql.append(SELECT).append(columns);
        return this;
    }

    public SqlWrapper delete() {
        sql.append(DELETE);
        return this;
    }

    public SqlWrapper update(String tableName) {
        sql.append(UPDATE).append(tableName);
        return this;
    }

    public SqlWrapper set() {
        sql.append(SET);
        return this;
    }

    public SqlWrapper count(String fieldName) {
        sql.append(COUNT).append("(").append(fieldName).append(")");
        return this;
    }

    public SqlWrapper sum(String fieldName) {
        sql.append(SUM).append("(").append(fieldName).append(")");
        return this;
    }

    public SqlWrapper distinct(String fieldName) {
        sql.append(DISTINCT).append(fieldName);
        return this;
    }

    public SqlWrapper from(String tableName) {
        sql.append(FROM).append(tableName);
        return this;
    }

    public SqlWrapper innerJoin(String tableName) {
        sql.append(INNER_JOIN).append(tableName);
        return this;
    }

    public SqlWrapper leftJoin(String tableName) {
        sql.append(LEFT_JOIN).append(tableName);
        return this;
    }

    public SqlWrapper rightJoin(String tableName) {
        sql.append(RIGHT_JOIN).append(tableName);
        return this;
    }

    public SqlWrapper union(String otherQuerySql) {
        sql.append(UNION).append(otherQuerySql);
        return this;
    }

    public SqlWrapper unionAll(String otherQuerySql) {
        sql.append(UNION_ALL).append(otherQuerySql);
        return this;
    }

    public SqlWrapper exists(String subQuerySql) {
        sql.append(EXISTS).append("(").append(subQuerySql).append(")");
        return this;
    }

    public SqlWrapper notExists(String subQuerySql) {
        sql.append(NOT_EXISTS).append("(").append(subQuerySql).append(")");
        return this;
    }

    public SqlWrapper on(String fieldName, String refFieldName) {
        sql.append(ON).append(fieldName).append(" = ").append(refFieldName);
        return this;
    }

    public SqlWrapper where() {
        sql.append(WHERE);
        return this;
    }

    public SqlWrapper oneEqOne() {
        /* default condition */
        sql.append("1=1").append(AND);
        return this;
    }

    public SqlWrapper and() {
        sql.append(AND);
        return this;
    }

    public SqlWrapper or() {
        sql.append(OR);
        return this;
    }

    public SqlWrapper like(String fieldName, CharSequence value) {
        sql.append(fieldName).append(LIKE).append("'%").append(value).append("%'");
        return this;
    }

    public SqlWrapper like(String fieldName, Number value) {
        sql.append(fieldName).append(LIKE).append("'%").append(value).append("%'");
        return this;
    }

    public SqlWrapper eq(String fieldName, CharSequence value) {
        sql.append(fieldName).append(" = ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper eq(String fieldName, Number value) {
        sql.append(fieldName).append(" = ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper notEq(String fieldName, CharSequence value) {
        sql.append(fieldName).append(" != ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper notEq(String fieldName, Number value) {
        sql.append(fieldName).append(" != ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper gt(String fieldName, CharSequence value) {
        sql.append(fieldName).append(" > ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper gt(String fieldName, Number value) {
        sql.append(fieldName).append(" > ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper gte(String fieldName, CharSequence value) {
        sql.append(fieldName).append(" >= ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper gte(String fieldName, Number value) {
        sql.append(fieldName).append(" >= ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper lt(String fieldName, CharSequence value) {
        sql.append(fieldName).append(" < ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper lt(String fieldName, Number value) {
        sql.append(fieldName).append(" < ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper lte(String fieldName, CharSequence value) {
        sql.append(fieldName).append(" <= ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper lte(String fieldName, Number value) {
        sql.append(fieldName).append(" <= ").append("'").append(value).append("'");
        return this;
    }

    public SqlWrapper in(String fieldName, Collection<?> values) {
        String str = this.spilt(values);
        sql.append(fieldName).append(IN).append("(").append(str).append(")");
        return this;
    }

    public SqlWrapper notIn(String fieldName, Collection<?> values) {
        String str = this.spilt(values);
        sql.append(fieldName).append(NOT_IN).append("(").append(str).append(")");
        return this;
    }

    public SqlWrapper isNull(String fieldName) {
        sql.append(fieldName).append(IS_NULL);
        return this;
    }

    public SqlWrapper notNull(String fieldName) {
        sql.append(fieldName).append(IS_NOT_NULL);
        return this;
    }

    public SqlWrapper groupBy(String columns) {
        /* 多个字段时须按逗号分隔 */
        sql.append(GROUP_BY).append(columns);
        return this;
    }

    public SqlWrapper orderBy(String columns, boolean isDesc) {
        /* 多个字段时须按逗号分隔 */
        if (isDesc) {
            sql.append(ORDER_BY).append(columns).append(DESC);
        } else {
            sql.append(ORDER_BY).append(columns).append(ASC);
        }
        return this;
    }

    public SqlWrapper having() {
        sql.append(HAVING);
        return this;
    }

    private String spilt(Collection<?> values) {
        if (values == null || values.size() == 0) {
            throw new IllegalArgumentException("Values must be not empty.");
        }
        StringBuilder str = new StringBuilder();
        int index = 0, total = values.size();
        for (Object value : values) {
            if (!(value instanceof CharSequence || value instanceof Number)) {
                throw new IllegalArgumentException("Values must be String or Number.");
            }
            str.append(value.toString());
            if (index < (total - 1)) {
                str.append(",");
            }
            index++;
        }
        return str.toString();
    }

    interface Constant {
        String SELECT = " SELECT ";
        String UPDATE = " UPDATE ";
        String DELETE = " DELETE ";
        String SET = " SET ";
        String COUNT = " COUNT ";
        String SUM = " SUM ";
        String DISTINCT = " DISTINCT ";
        String FROM = " FROM ";
        String WHERE = " WHERE ";
        String INNER_JOIN = " INNER JOIN ";
        String RIGHT_JOIN = " RIGHT JOIN ";
        String LEFT_JOIN = " LEFT JOIN ";
        String UNION = " UNION ";
        String UNION_ALL = " UNION ALL ";
        String EXISTS = " EXISTS ";
        String NOT_EXISTS = " NOT EXISTS ";
        String ON = " ON ";
        String AS = " AS ";
        String AND = " AND ";
        String OR = " OR ";
        String LIKE = " LIKE ";
        String IN = " IN ";
        String NOT_IN = " NOT IN ";
        String IS_NULL = " IS NULL ";
        String IS_NOT_NULL = " IS NOT NULL ";
        String GROUP_BY = " GROUP BY ";
        String ORDER_BY = " ORDER BY ";
        String HAVING = " HAVING ";
        String ASC = " ASC ";
        String DESC = " DESC ";
    }

}